@@ -175,7 +175,7 @@ class JavaTraceback(Traceback):
             unknown_source = True
 
         # split on ' ', '(', ')', ':'
-        tokens = re.split(" |\(|\)|:", line_string.strip())
+        tokens = re.split(r" |\(|\)|:", line_string.strip())
 
         if tokens[0] != "at" or len(tokens) != 5:
             raise ParseException("Invalid Java Exception")
@@ -208,8 +208,45 @@ class JavaTraceback(Traceback):
         return [f for f in git_files if f.endswith(trace_filename)]
 
 
+class JavaScriptTraceback(Traceback):
+    # This class matches a stacktrace that looks similar to https://v8.dev/docs/stack-trace-api
+
+    def extract_traceback(self, lines):
+        if not lines[0].startswith('\t'):
+            self.header = lines[0] + '\n'
+        lines = [line for line in lines if line.startswith('\t')]
+        extracted = []
+        for line in lines:
+            extracted.append(self._extract_line(line))
+        self.lines = extracted
+        if not self.lines:
+            raise ParseException("Failed to parse stacktrace")
+
+    def _extract_line(self, line_string):
+        pattern = r"\tat\s(?P<symbol>[^\s(]*)?(?:\s*)?\(?(?P<path>[^\s\?]+)(?:\S*)?\:(?P<line>\d+):(?:\d+)\)?"
+        result = re.match(pattern, line_string)
+
+        if result:
+            frame = result.groupdict()
+        else:
+            log.debug("Failed to parse frame %s", line_string)
+            raise ParseException
+
+        return Line(frame.get('path'), frame.get('line'), frame.get('symbol'), None)
+
+    def traceback_format(self):
+        return [line.traceback_format() for line in self.lines]
+
+    def format_lines(self):
+        lines = self.traceback_format()
+        return ''.join(traceback.format_list(lines))
+
+    def file_match(self, trace_filename, git_files):
+        return [f for f in git_files if f.endswith(trace_filename)]
+
+
 def parse_trace(traceback_string):
-    languages = [PythonTraceback, JavaTraceback]
+    languages = [PythonTraceback, JavaTraceback, JavaScriptTraceback]
     for language in languages:
         try:
             return language(traceback_string)
